==> knative-model-4.9.2-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/BrokerSpecFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.dev.duck.v1beta1.DeliverySpecFluent;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpec;
import java.lang.String;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpecFluent;
import io.fabric8.knative.duck.v1.KReference;
import io.fabric8.knative.duck.v1.KReferenceFluent;
import io.fabric8.knative.dev.duck.v1beta1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.duck.v1.KReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpecBuilder;
import java.util.Map;
import io.fabric8.knative.dev.duck.v1beta1.DeliverySpec;

public interface BrokerSpecFluent<A extends BrokerSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplateSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ChannelTemplateSpec getChannelTemplateSpec();
    public ChannelTemplateSpec buildChannelTemplateSpec();
    public A withChannelTemplateSpec(ChannelTemplateSpec channelTemplateSpec);
    public Boolean hasChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> withNewChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> withNewChannelTemplateSpecLike(ChannelTemplateSpec item);
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editOrNewChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editOrNewChannelTemplateSpecLike(ChannelTemplateSpec item);
    
/**
 * This method has been deprecated, please use method buildConfig instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public KReference getConfig();
    public KReference buildConfig();
    public A withConfig(KReference config);
    public Boolean hasConfig();
    public A withNewConfig(String apiVersion,String kind,String name,String namespace);
    public BrokerSpecFluent.ConfigNested<A> withNewConfig();
    public BrokerSpecFluent.ConfigNested<A> withNewConfigLike(KReference item);
    public BrokerSpecFluent.ConfigNested<A> editConfig();
    public BrokerSpecFluent.ConfigNested<A> editOrNewConfig();
    public BrokerSpecFluent.ConfigNested<A> editOrNewConfigLike(KReference item);
    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public DeliverySpec getDelivery();
    public DeliverySpec buildDelivery();
    public A withDelivery(DeliverySpec delivery);
    public Boolean hasDelivery();
    public BrokerSpecFluent.DeliveryNested<A> withNewDelivery();
    public BrokerSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
    public BrokerSpecFluent.DeliveryNested<A> editDelivery();
    public BrokerSpecFluent.DeliveryNested<A> editOrNewDelivery();
    public BrokerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);

    public interface ChannelTemplateSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ChannelTemplateSpecFluent<BrokerSpecFluent.ChannelTemplateSpecNested<N>>{

        
    public N and();    public N endChannelTemplateSpec();
}
    public interface ConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<BrokerSpecFluent.ConfigNested<N>>{

        
    public N and();    public N endConfig();
}
    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeliverySpecFluent<BrokerSpecFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}


}

==> knative-model-4.11.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/BrokerSpecFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpecFluent;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpec;
import java.lang.String;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpecFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpecBuilder;
import java.util.Map;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpec;

public interface BrokerSpecFluent<A extends BrokerSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplateSpec instead.
 * @return The buildable object.
 */
@Deprecated public ChannelTemplateSpec getChannelTemplateSpec();
    public ChannelTemplateSpec buildChannelTemplateSpec();
    public A withChannelTemplateSpec(ChannelTemplateSpec channelTemplateSpec);
    public Boolean hasChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> withNewChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> withNewChannelTemplateSpecLike(ChannelTemplateSpec item);
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editOrNewChannelTemplateSpec();
    public BrokerSpecFluent.ChannelTemplateSpecNested<A> editOrNewChannelTemplateSpecLike(ChannelTemplateSpec item);
    
/**
 * This method has been deprecated, please use method buildConfig instead.
 * @return The buildable object.
 */
@Deprecated public KReference getConfig();
    public KReference buildConfig();
    public A withConfig(KReference config);
    public Boolean hasConfig();
    public A withNewConfig(String apiVersion,String kind,String name,String namespace);
    public BrokerSpecFluent.ConfigNested<A> withNewConfig();
    public BrokerSpecFluent.ConfigNested<A> withNewConfigLike(KReference item);
    public BrokerSpecFluent.ConfigNested<A> editConfig();
    public BrokerSpecFluent.ConfigNested<A> editOrNewConfig();
    public BrokerSpecFluent.ConfigNested<A> editOrNewConfigLike(KReference item);
    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@Deprecated public DeliverySpec getDelivery();
    public DeliverySpec buildDelivery();
    public A withDelivery(DeliverySpec delivery);
    public Boolean hasDelivery();
    public BrokerSpecFluent.DeliveryNested<A> withNewDelivery();
    public BrokerSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
    public BrokerSpecFluent.DeliveryNested<A> editDelivery();
    public BrokerSpecFluent.DeliveryNested<A> editOrNewDelivery();
    public BrokerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);

    public interface ChannelTemplateSpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ChannelTemplateSpecFluent<BrokerSpecFluent.ChannelTemplateSpecNested<N>>{

        
    public N and();    public N endChannelTemplateSpec();
}
    public interface ConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<BrokerSpecFluent.ConfigNested<N>>{

        
    public N and();    public N endConfig();
}
    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeliverySpecFluent<BrokerSpecFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}


}
